@@ -49,7 +49,7 @@
 // #define CURL_NO_OLDIES
 #include <curl/curl.h>
 #include <ug_plugin.h>
-#include <ug_url.h>
+#include <ug_data_download.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -61,51 +61,37 @@ typedef	struct	UgPluginCurl_	UgPluginCurl;
 extern	const	UgPluginClass*	UgPluginCurlClass;
 
 
-struct UgPluginCurl_ {
+struct UgPluginCurl_
+{
 	UG_PLUGIN_MEMBERS;
 //	const UgPluginClass*	plugin_class;
-//	GMutex*					lock;
-//	UgDataset*				dataset;
-//	UgMessage*				queue;
-//	UgState					state;
 //	guint					ref_count;
+//	GMutex*					lock;
+//	UgMessage*				messages;
+//	UgState					state;
 
-	gboolean		error_occurred;
+	// supported data
+	UgDataCommon*	common;
+	UgDataProxy*	proxy;
+	UgDataHttp*		http;
+	UgDataFtp*		ftp;
+
+	// status
+	guint			scheme;
 	gboolean		resumable;
 
-	// retry
-	guint			retry_limit;
-	guint			retry_count;
-	guint			retry_delay;	// seconds
-
-	// proxy
-	gint			proxy_list_length;
-	gint			proxy_list_index;
-
-	// URL parts
-	UgUrlPart		urlpart;
-
-	// http referer
-	gchar*			http_referer;
-	// redirection - for HTTP header "Location:"
-	gboolean		redirection;
-	gint			redirection_count;
-	gint			redirection_limit;		// default value is 30
-
 	// progress
-	guint			progress_callback_counts;
-	gint64			complete_size;
-	gint64			total_size;
-	GTimer*			timer;
-	gdouble			consumed_time;
-	gdouble			current_speed;
+	guint			progress_count;
+	gdouble			file_beg;
+	gdouble			file_end;				// file size
 
 	// file output
 	gchar*			path;
 	guint			path_folder_len;		// folder length for path
 	gchar*			path_tmp;
 	FILE*			file_stream;			// ug_plugin_curl_open_file ()
-	curl_off_t		file_offset_beg;
+	curl_off_t		file_offset;
+	curl_off_t		file_offset_old;
 	// file input
 	FILE*			file_stream_in;
 
@@ -120,5 +106,5 @@ struct UgPluginCurl_ {
 }
 #endif
 
-#endif  // End of UG_PLUGIN_CURL_H
+#endif  // UG_PLUGIN_CURL_H
 
