@@ -375,8 +375,8 @@ gboolean	ug_html_context_parse (UgHtmlContext* context_pub, const char* buffer,
 
 gboolean	ug_html_context_parse_file (UgHtmlContext* context, const char* file_utf8)
 {
-	char*	buffer;
-	gint	buffer_len;
+	char*	buf;
+	gint	buf_len;
 	gint	fd;
 
 //	fd = open (file_utf8, O_RDONLY | O_TEXT, S_IREAD);
@@ -384,13 +384,15 @@ gboolean	ug_html_context_parse_file (UgHtmlContext* context, const char* file_ut
 	if (fd == -1)
 		return FALSE;
 
-	buffer = g_malloc (4096);
-	do {
-//		buffer_len = read (fd, buffer, 4096);
-		buffer_len = ug_fd_read (fd, buffer, 4096);
-		ug_html_context_parse (context, buffer, buffer_len);
-	} while (buffer_len);
-	g_free (buffer);
+	buf = g_malloc (4096);
+	for (;;) {
+//		buf_len = read (fd, buf, 4096);
+		buf_len = ug_fd_read (fd, buf, 4096);
+		if (buf_len <= 0)
+			break;
+		ug_html_context_parse (context, buf, buf_len);
+	}
+	g_free (buf);
 
 //	close (fd);
 	ug_fd_close (fd);
@@ -480,8 +482,8 @@ static void	cb_start_element (UgHtmlContextPrivate* context,
 		for (; *attribute_names; attribute_names++, attribute_values++) {
 			if (g_ascii_strcasecmp (*attribute_names, filter->attr_name) != 0)
 				continue;
-			if (filter->add_value)
-				filter->add_value (filter, *attribute_values, filter->user_data);
+			if (filter->callback)
+				filter->callback (filter, *attribute_values, filter->callback_data);
 			else
 				filter->attr_values = g_list_prepend (filter->attr_values, g_strdup (*attribute_values));
 		}
